@@ -1,8 +1,10 @@
+'use strict';
+
 var extend = require('../index');
 var test = require('tape');
 
 var str = 'me a test';
-var int = 10;
+var integer = 10;
 var arr = [1, 'what', new Date(81, 8, 4)];
 var date = new Date(81, 4, 13);
 
@@ -10,24 +12,24 @@ var Foo = function () {};
 
 var obj = {
 	str: str,
-	int: int,
+	integer: integer,
 	arr: arr,
 	date: date,
 	constructor: 'fake',
 	isPrototypeOf: 'not a function',
-    foo: new Foo()
+	foo: new Foo()
 };
 
 var deep = {
 	ori: obj,
 	layer: {
-		int: 10,
+		integer: 10,
 		str: 'str',
 		date: new Date(84, 5, 12),
 		arr: [101, 'dude', new Date(82, 10, 4)],
 		deep: {
 			str: obj.str,
-			int: int,
+			integer: integer,
 			arr: obj.arr,
 			date: new Date(81, 7, 4)
 		}
@@ -106,7 +108,7 @@ test('merge string with obj', function (t) {
 	t.equal(ori, 'what u gonna say', 'original string is unchanged');
 	var testObj = {
 		str: 'me a test',
-		int: 10,
+		integer: 10,
 		arr: [1, 'what', new Date(81, 8, 4)],
 		date: new Date(81, 4, 13),
 		constructor: 'fake',
@@ -168,7 +170,7 @@ test('merge number with object', function (t) {
 	var target = extend(20, obj);
 	var testObj = {
 		str: 'me a test',
-		int: 10,
+		integer: 10,
 		arr: [1, 'what', new Date(81, 8, 4)],
 		date: new Date(81, 4, 13),
 		constructor: 'fake',
@@ -239,7 +241,7 @@ test('merge array with object', function (t) {
 	var target = extend(ori, obj);
 	var testObject = {
 		str: 'me a test',
-		int: 10,
+		integer: 10,
 		arr: [1, 'what', new Date(81, 8, 4)],
 		date: new Date(81, 4, 13),
 		constructor: 'fake',
@@ -250,13 +252,13 @@ test('merge array with object', function (t) {
 	t.deepEqual(obj, testObject, 'obj is unchanged');
 	t.equal(ori.length, 6, 'array has proper length');
 	t.equal(ori.str, obj.str, 'array has obj.str property');
-	t.equal(ori.int, obj.int, 'array has obj.int property');
+	t.equal(ori.integer, obj.integer, 'array has obj.integer property');
 	t.deepEqual(ori.arr, obj.arr, 'array has obj.arr property');
 	t.equal(ori.date, obj.date, 'array has obj.date property');
 
 	t.equal(target.length, 6, 'target has proper length');
 	t.equal(target.str, obj.str, 'target has obj.str property');
-	t.equal(target.int, obj.int, 'target has obj.int property');
+	t.equal(target.integer, obj.integer, 'target has obj.integer property');
 	t.deepEqual(target.arr, obj.arr, 'target has obj.arr property');
 	t.equal(target.date, obj.date, 'target has obj.date property');
 	t.end();
@@ -319,7 +321,7 @@ test('merge date with object', function (t) {
 	var testDate = new Date(81, 8, 4);
 	var testObject = {
 		str: 'me a test',
-		int: 10,
+		integer: 10,
 		arr: [1, 'what', testDate],
 		date: new Date(81, 4, 13),
 		constructor: 'fake',
@@ -337,7 +339,7 @@ test('merge object with string', function (t) {
 	var testDate = new Date(81, 7, 26);
 	var ori = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: testDate
 	};
@@ -353,7 +355,7 @@ test('merge object with string', function (t) {
 		7: 's',
 		8: 't',
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: testDate
 	};
@@ -367,13 +369,13 @@ test('merge object with string', function (t) {
 test('merge object with number', function (t) {
 	var ori = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26)
 	};
 	var testObject = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26)
 	};
@@ -386,7 +388,7 @@ test('merge object with number', function (t) {
 test('merge object with array', function (t) {
 	var ori = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26)
 	};
@@ -396,7 +398,7 @@ test('merge object with array', function (t) {
 		1: 'what',
 		2: new Date(81, 8, 4),
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26)
 	};
@@ -410,14 +412,14 @@ test('merge object with array', function (t) {
 test('merge object with date', function (t) {
 	var ori = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26)
 	};
 	var target = extend(ori, date);
 	var testObject = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26)
 	};
@@ -431,7 +433,7 @@ test('merge object with date', function (t) {
 test('merge object with object', function (t) {
 	var ori = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26),
 		foo: 'bar'
@@ -439,7 +441,7 @@ test('merge object with object', function (t) {
 	var target = extend(ori, obj);
 	var expectedObj = {
 		str: 'me a test',
-		int: 10,
+		integer: 10,
 		arr: [1, 'what', new Date(81, 8, 4)],
 		date: new Date(81, 4, 13),
 		constructor: 'fake',
@@ -448,10 +450,9 @@ test('merge object with object', function (t) {
 	};
 	var expectedTarget = {
 		str: 'me a test',
-		int: 10,
+		integer: 10,
 		arr: [1, 'what', new Date(81, 8, 4)],
 		date: new Date(81, 4, 13),
-		foo: 'bar',
 		constructor: 'fake',
 		isPrototypeOf: 'not a function',
 		foo: new Foo()
@@ -466,25 +467,21 @@ test('merge object with object', function (t) {
 test('deep clone', function (t) {
 	var ori = {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26),
-		layer: {
-			deep: {
-				int: 42
-			}
-		}
+		layer: { deep: { integer: 42 } }
 	};
 	var target = extend(true, ori, deep);
 
 	t.deepEqual(ori, {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26),
 		ori: {
 			str: 'me a test',
-			int: 10,
+			integer: 10,
 			arr: [1, 'what', new Date(81, 8, 4)],
 			date: new Date(81, 4, 13),
 			constructor: 'fake',
@@ -492,13 +489,13 @@ test('deep clone', function (t) {
 			foo: new Foo()
 		},
 		layer: {
-			int: 10,
+			integer: 10,
 			str: 'str',
 			date: new Date(84, 5, 12),
 			arr: [101, 'dude', new Date(82, 10, 4)],
 			deep: {
 				str: 'me a test',
-				int: 10,
+				integer: 10,
 				arr: [1, 'what', new Date(81, 8, 4)],
 				date: new Date(81, 7, 4)
 			}
@@ -507,7 +504,7 @@ test('deep clone', function (t) {
 	t.deepEqual(deep, {
 		ori: {
 			str: 'me a test',
-			int: 10,
+			integer: 10,
 			arr: [1, 'what', new Date(81, 8, 4)],
 			date: new Date(81, 4, 13),
 			constructor: 'fake',
@@ -515,13 +512,13 @@ test('deep clone', function (t) {
 			foo: new Foo()
 		},
 		layer: {
-			int: 10,
+			integer: 10,
 			str: 'str',
 			date: new Date(84, 5, 12),
 			arr: [101, 'dude', new Date(82, 10, 4)],
 			deep: {
 				str: 'me a test',
-				int: 10,
+				integer: 10,
 				arr: [1, 'what', new Date(81, 8, 4)],
 				date: new Date(81, 7, 4)
 			}
@@ -529,12 +526,12 @@ test('deep clone', function (t) {
 	}, 'deep is unchanged');
 	t.deepEqual(target, {
 		str: 'no shit',
-		int: 76,
+		integer: 76,
 		arr: [1, 2, 3, 4],
 		date: new Date(81, 7, 26),
 		ori: {
 			str: 'me a test',
-			int: 10,
+			integer: 10,
 			arr: [1, 'what', new Date(81, 8, 4)],
 			date: new Date(81, 4, 13),
 			constructor: 'fake',
@@ -542,13 +539,13 @@ test('deep clone', function (t) {
 			foo: new Foo()
 		},
 		layer: {
-			int: 10,
+			integer: 10,
 			str: 'str',
 			date: new Date(84, 5, 12),
 			arr: [101, 'dude', new Date(82, 10, 4)],
 			deep: {
 				str: 'me a test',
-				int: 10,
+				integer: 10,
 				arr: [1, 'what', new Date(81, 8, 4)],
 				date: new Date(81, 7, 4)
 			}
@@ -559,7 +556,7 @@ test('deep clone', function (t) {
 	t.deepEqual(deep, {
 		ori: {
 			str: 'me a test',
-			int: 10,
+			integer: 10,
 			arr: [1, 'what', new Date(81, 8, 4)],
 			date: new Date(81, 4, 13),
 			constructor: 'fake',
@@ -567,32 +564,26 @@ test('deep clone', function (t) {
 			foo: new Foo()
 		},
 		layer: {
-			int: 10,
+			integer: 10,
 			str: 'str',
 			date: new Date(84, 5, 12),
 			arr: [101, 'dude', new Date(82, 10, 4)],
 			deep: {
 				str: 'me a test',
-				int: 10,
+				integer: 10,
 				arr: [1, 'what', new Date(81, 8, 4)],
 				date: new Date(81, 7, 4)
 			}
 		}
 	}, 'deep is unchanged after setting target property');
-	//----- NEVER USE EXTEND WITH THE ABOVE SITUATION ------------------------------
+	// ----- NEVER USE EXTEND WITH THE ABOVE SITUATION ------------------------------
 	t.end();
 });
 
 test('deep clone; arrays are merged', function (t) {
-	var defaults = {
-		arr: [1, 2, 3]
-	};
-	var override = {
-		arr: ['x']
-	};
-	var expectedTarget = {
-		arr: ['x', 2, 3]
-	};
+	var defaults = { arr: [1, 2, 3] };
+	var override = { arr: ['x'] };
+	var expectedTarget = { arr: ['x', 2, 3] };
 
 	var target = extend(true, defaults, override);
 
@@ -601,23 +592,49 @@ test('deep clone; arrays are merged', function (t) {
 });
 
 test('deep clone === false; objects merged normally', function (t) {
-	var defaults = {
-		a: 1
-	};
-	var override = {
-		a: 2
-	};
+	var defaults = { a: 1 };
+	var override = { a: 2 };
 	var target = extend(false, defaults, override);
 	t.deepEqual(target, override, 'deep === false handled normally');
 	t.end();
 });
 
 test('pass in null; should create a valid object', function (t) {
-	var override = {
-		a: 1
-	};
+	var override = { a: 1 };
 	var target = extend(null, override);
 	t.deepEqual(target, override, 'null object handled normally');
 	t.end();
 });
 
+test('works without Array.isArray', function (t) {
+	var savedIsArray = Array.isArray;
+	Array.isArray = false; // don't delete, to preserve enumerability
+	var target = [];
+	var source = [1, [2], { 3: true }];
+	t.deepEqual(
+		extend(true, target, source),
+		[1, [2], { 3: true }],
+		'It works without Array.isArray'
+	);
+	Array.isArray = savedIsArray;
+	t.end();
+});
+
+test('non-object target', function (t) {
+	t.deepEqual(extend(3.14, { a: 'b' }), { a: 'b' });
+	t.deepEqual(extend(true, 3.14, { a: 'b' }), { a: 'b' });
+
+	t.end();
+});
+
+test('__proto__ is merged as an own property', function (t) {
+	var malicious = { fred: 1 };
+	Object.defineProperty(malicious, '__proto__', { value: { george: 1 }, enumerable: true });
+	var target = {};
+	extend(true, target, malicious);
+	t.notOk(target.george);
+	t.ok(Object.prototype.hasOwnProperty.call(target, '__proto__'));
+	t.deepEqual(Object.getOwnPropertyDescriptor(target, '__proto__').value, { george: 1 });
+
+	t.end();
+});
